==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/plugins/General/scrobbler/translations/scrobbler_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>ScrobblerFactory</name>
    <message>
        <location filename="../scrobblerfactory.cpp" line="31"/>
        <source>Scrobbler Plugin</source>
        <translation>Modul Scrobbler</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="51"/>
        <source>About Scrobbler Plugin</source>
        <translation>O modulu Scrobbler</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="52"/>
        <source>Qmmp AudioScrobbler Plugin</source>
        <translation>Modul Qmmp Scrobbler</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Scrobbler Plugin Settings</source>
        <translation>Nastavení modulu Scrobbler</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="20"/>
        <source>Last.fm</source>
        <translation>Last.fm</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="31"/>
        <location filename="../settingsdialog.ui" line="104"/>
        <location filename="../settingsdialog.ui" line="160"/>
        <source>Session:</source>
        <translation>Sezení:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <location filename="../settingsdialog.ui" line="117"/>
        <location filename="../settingsdialog.ui" line="173"/>
        <source>Check</source>
        <translation>Zkontrolovat</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <location filename="../settingsdialog.ui" line="95"/>
        <location filename="../settingsdialog.ui" line="151"/>
        <source>Register new session</source>
        <translation>Registrovat nové sezení</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="73"/>
        <source>Libre.fm</source>
        <translation>Libre.fm</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="129"/>
        <source>ListenBrainz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="126"/>
        <location filename="../settingsdialog.cpp" line="152"/>
        <location filename="../settingsdialog.cpp" line="217"/>
        <source>Message</source>
        <translation>Zpráva</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="127"/>
        <source>1. Wait for browser startup</source>
        <translation>1. Vyčkejte startu prohlížeče</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="128"/>
        <source>2. Allow Qmmp to scrobble tracks to your %1 account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="129"/>
        <source>3. Press &quot;OK&quot;</source>
        <translation>3. Stlačte „OK“</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="134"/>
        <location filename="../settingsdialog.cpp" line="138"/>
        <location filename="../settingsdialog.cpp" line="172"/>
        <location filename="../settingsdialog.cpp" line="176"/>
        <location filename="../settingsdialog.cpp" line="227"/>
        <location filename="../settingsdialog.cpp" line="231"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="134"/>
        <location filename="../settingsdialog.cpp" line="172"/>
        <location filename="../settingsdialog.cpp" line="227"/>
        <source>Network error</source>
        <translation>Síťová chyba</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="138"/>
        <location filename="../settingsdialog.cpp" line="176"/>
        <source>Unable to register new session</source>
        <translation>Nelze registrovat nové sezení</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="152"/>
        <source>New session has been received successfully</source>
        <translation>Nové sezení bylo úspěšně přijato</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="217"/>
        <source>Permission granted</source>
        <translation>Přístup povolen </translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="231"/>
        <source>Permission denied</source>
        <translation>Přístup odmítnut</translation>
    </message>
</context>
</TS>

==> qmmp_1.1.4.orig.tar.bz2: qmmp-1.1.4/src/plugins/General/scrobbler/translations/scrobbler_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>ScrobblerFactory</name>
    <message>
        <location filename="../scrobblerfactory.cpp" line="31"/>
        <source>Scrobbler Plugin</source>
        <translation>Modul Scrobbler</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="51"/>
        <source>About Scrobbler Plugin</source>
        <translation>O modulu Scrobbler</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="52"/>
        <source>Qmmp AudioScrobbler Plugin</source>
        <translation>Modul Qmmp Scrobbler</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Scrobbler Plugin Settings</source>
        <translation>Nastavení modulu Scrobbler</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Last.fm</source>
        <translation>Last.fm</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="40"/>
        <location filename="../settingsdialog.ui" line="113"/>
        <source>Session:</source>
        <translation>Sezení:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="50"/>
        <location filename="../settingsdialog.ui" line="126"/>
        <source>Check</source>
        <translation>Zkontrolovat</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="72"/>
        <location filename="../settingsdialog.ui" line="104"/>
        <source>Register new session</source>
        <translation>Registrovat nové sezení</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="82"/>
        <source>Libre.fm</source>
        <translation>Libre.fm</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="86"/>
        <location filename="../settingsdialog.cpp" line="121"/>
        <location filename="../settingsdialog.cpp" line="172"/>
        <source>Message</source>
        <translation>Zpráva</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="87"/>
        <source>1. Wait for browser startup</source>
        <translation>1. Vyčkejte startu prohlížeče</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="88"/>
        <source>2. Allow Qmmp to scrobble tracks to your %1 account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="90"/>
        <source>3. Press &quot;OK&quot;</source>
        <translation>3. Stlačte „OK“</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="103"/>
        <location filename="../settingsdialog.cpp" line="107"/>
        <location filename="../settingsdialog.cpp" line="136"/>
        <location filename="../settingsdialog.cpp" line="140"/>
        <location filename="../settingsdialog.cpp" line="180"/>
        <location filename="../settingsdialog.cpp" line="184"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="103"/>
        <location filename="../settingsdialog.cpp" line="136"/>
        <location filename="../settingsdialog.cpp" line="180"/>
        <source>Network error</source>
        <translation>Síťová chyba</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="107"/>
        <location filename="../settingsdialog.cpp" line="140"/>
        <source>Unable to register new session</source>
        <translation>Nelze registrovat nové sezení</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="121"/>
        <source>New session has been received successfully</source>
        <translation>Nové sezení bylo úspěšně přijato</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="172"/>
        <source>Permission granted</source>
        <translation>Přístup povolen </translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="184"/>
        <source>Permission denied</source>
        <translation>Přístup odmítnut</translation>
    </message>
</context>
</TS>
